@@ -129,13 +129,14 @@ def test_token_polarity(
         lexicon=lexicon, lowercase=lowercase, lemmatize=lemmatize
     )
     is_negation_getter = make_is_negation_getter(negations=negations)
+    is_negated_getter = make_is_negated_getter(is_negation_getter=is_negation_getter)
     intensifier_getter = make_intensifier_getter(
         intensifiers=intensifiers, lowercase=lowercase, lemmatize=lemmatize
     )
 
     polarity_getter = make_token_polarity_getter(
         valence_getter=valence_getter,
-        is_negation_getter=is_negation_getter,
+        is_negated_getter=is_negated_getter,
         intensifier_getter=intensifier_getter,
     )
     Token.set_extension("polarity", getter=polarity_getter, force=True)
@@ -149,6 +150,9 @@ def test_token_polarity(
     [
         ("jeg er glad", "positive", "da"),
         ("jeg er sur", "negative", "da"),
+        ("jeg er sur?", "negative", "da"),
+        ("jeg er sur!", "negative", "da"),
+        ("", "neutral", "da"),
         ("filmen var okay god men er generelt skuffet", "negative", "da"),
     ],
 )
@@ -193,9 +197,11 @@ def test_span_doc_polarity(example: str, expected: str, lang: str, nlp_dict):
         assert sent._.polarity.compound > 0
     elif expected == "negative":
         assert sent._.polarity.compound < 0
+    elif expected == "neutral":
+        assert sent._.polarity.compound == 0
     else:
         raise ValueError(
-            "Invalid expected value '{expected}', should be either 'positive' or 'negative'"
+            "Invalid expected value '{expected}', should be either 'neutral', 'positive' or 'negative'"
         )
 
 
@@ -225,8 +231,8 @@ def test_span_polarity_contrast(
 @pytest.mark.parametrize(
     "example,lang",
     [
-        ("jeg er glad", "da"),
         ("I am happy", "en"),
+        ("jeg er glad", "da"),
         ("jeg er glad", "no"),
         ("jag är glad", "sv"),
     ],
